@@ -2,10 +2,11 @@ use 5.10.0;
 use warnings;
 #no warnings 'experimental';
 use strict 'vars';
+#use Carp::Always;
 
 package Text::Bidi;
 # ABSTRACT: Unicode bidi algorithm using libfribidi
-$Text::Bidi::VERSION = '2.10';
+$Text::Bidi::VERSION = '2.12';
 use Exporter;
 use base qw(Exporter);
 use Carp;
@@ -64,11 +65,13 @@ sub new {
 
 sub tie_byte {
     my $self = shift;
+    return \undef unless defined $_[0];
     $self->{'tie_byte'}->new(@_)
 }
 
 sub tie_long {
     my $self = shift;
+    return \undef unless defined $_[0];
     $self->{'tie_long'}->new(@_)
 }
 
@@ -140,7 +143,7 @@ sub shaped {
     my $self = S(@_);
     my ($flags, $el, $prop, $u) = @_;
     return ($prop, $u) unless defined $flags;
-    $flags ||= $Text::Bidi::privatec::FRIBIDI_FLAGS_ARABIC;
+    $flags ||= $Text::Bidi::private::FRIBIDI_FLAGS_ARABIC;
     my ($p, $v) =Text::Bidi::private::shape_arabic($flags, $$el, $$prop, 
         $$u);
     ($self->tie_byte($p), $self->tie_long($v))
@@ -193,11 +196,32 @@ sub reorder_map {
 
     $map = $self->tie_long($map) unless eval {defined $$map};
 
+
     my ($lev, $elout, $mout) = Text::Bidi::private::reorder_map(
         $flags, $$bt, $off, $len, $par, $$el, $$map);
+
     ($elout, $mout)
 }
 
+# TODO this doesn't work
+
+
+sub remove_bidi_marks {
+    my $self = S(@_);
+    my ($v, $to, $from, $levels) = @_;
+    $to = $self->tie_long($to) unless eval {defined $$to};
+    if ( defined($from) ) {
+        $from = $self->tie_long($from) unless eval {defined $$from};
+    } else {
+        $from = \undef;
+    }
+    $levels = $self->tie_byte($levels) unless eval {defined $$levels};
+    no warnings 'uninitialized';
+    my ($len, $vout, $toout, $fromout, $levelsout) = 
+      Text::Bidi::private::remove_bidi_marks($v, $$to, $$from, $$levels);
+    ($vout, $toout, $fromout, $levelsout)
+}
+
 
 sub log2vis {
     require Text::Bidi::Paragraph;
@@ -257,7 +281,7 @@ Text::Bidi - Unicode bidi algorithm using libfribidi
 
 =head1 VERSION
 
-version 2.10
+version 2.12
 
 =head1 SYNOPSIS
 
@@ -592,6 +616,28 @@ B<$elout>.
 
 =for Pod::Coverage hash2flags
 
+=begin comment
+
+
+
+
+=end comment
+
+method remove_bidi_marks
+
+    ($v, $to, $from, $levels) = 
+        $tb->remove_bidi_marks($v[, $to[, $from[, $levels]]])
+
+Remove the explicit bidi marks from C<$v>. The optional arguments, if given, 
+are the map from the logical to the visual string, the inverse map, and 
+embedding levels, respectively, as returned by L</reorder_map>. The inverse 
+map C<$from> can be obtained from the direct one C<$to> by a command like:
+
+    @$from[@$map] = 0..$#$map
+
+Each of the arguments can be C<undef>, in which case it will be skipped. This 
+implements step X9, see fribidi_remove_bidi_marks(3).
+
 =head1 BUGS
 
 There are no real tests for any of this.
@@ -619,7 +665,7 @@ Moshe Kamensky <kamensky@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Moshe Kamensky.
+This software is copyright (c) 2015 by Moshe Kamensky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
