@@ -4,14 +4,14 @@ use integer;
 use strict 'vars';
 package Text::Bidi::Constants;
 # ABSTRACT: Constants for Text::Bidi
-$Text::Bidi::Constants::VERSION = '2.10';
+$Text::Bidi::Constants::VERSION = '2.12';
 
 use Text::Bidi::private;
 SYM: for my $sym ( keys %Text::Bidi::private:: ) {
     next unless $sym =~ /^FRIBIDI_/;
 
 
-    for my $kind ( qw(Type Mask Par Flag) ) {
+    for my $kind ( qw(Type Mask Par Flag Flags) ) {
         if ( $sym =~ /FRIBIDI_\U${kind}\E_([A-Z_]*)$/ ) {
             *{"Text::Bidi::${kind}::$1"} = *{"Text::Bidi::private::$sym"};
             next SYM;
@@ -47,7 +47,7 @@ Text::Bidi::Constants - Constants for Text::Bidi
 
 =head1 VERSION
 
-version 2.10
+version 2.12
 
 =head1 DESCRIPTION
 
@@ -79,9 +79,10 @@ possible constants.
 
 =item *
 
-Constants of the form B<FRIBIDI_FLAG_FOO> are converted to 
-C<$Text::Bidi::Flag::FOO>. See fribidi_reorder_line(3) and fribidi_shape(3) 
-for possible constants. As a special case, B<FRIBIDI_FLAGS_ARABIC> becomes 
+Constants of the form B<FRIBIDI_FLAG_FOO> or B<FRIBIDI_FLAGS_FOO> are 
+converted to C<$Text::Bidi::Flag::FOO> or C<$Text::Bidi::Flag::FOO>. See 
+fribidi_reorder_line(3) and fribidi_shape(3) for possible constants. As a 
+special case, B<FRIBIDI_FLAGS_ARABIC> is also available as 
 C<$Text::Bidi::Flag::ARABIC>
 
 =item *
@@ -108,7 +109,7 @@ Moshe Kamensky <kamensky@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Moshe Kamensky.
+This software is copyright (c) 2015 by Moshe Kamensky.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
